@@ -14,7 +14,7 @@
 function setGeoLog() {
   if [[ -z "${GEOMESA_LOG_DIR}" ]]; then
     export GEOMESA_LOG_DIR="${GEOMESA_CASSANDRA_HOME}/logs"
-    export GEOMESA_OPTS="-Dgeomesa.log.dir=${GEOMESA_LOG_DIR} $GEOMESA_OPTS"
+    export GEOMESA_OPTS="-Dgeomesa.log.dir=${GEOMESA_LOG_DIR} ${GEOMESA_OPTS}"
   fi
   if [[ ! -d "${GEOMESA_LOG_DIR}" ]]; then
     mkdir "${GEOMESA_LOG_DIR}"
@@ -27,13 +27,13 @@ function findJars() {
   CP=()
   if [[ -d "${home}" ]]; then
     if [[ "$3" == "true" ]]; then
-      for jar in $(find ${home} -maxdepth 1 -iname "*.jar" -type f); do
+      for jar in $(find -L ${home} -maxdepth 1 -iname "*.jar" -type f); do
         if [[ "$jar" != *-sources.jar && ("$2" != "true" || "$jar" != *slf4j*) ]]; then
           CP+=(${jar})
         fi
       done
     else
-      for jar in $(find ${home} -type f -iname "*.jar"); do
+      for jar in $(find -L ${home} -type f -iname "*.jar"); do
         if [[ "$jar" != *-sources.jar && ("$2" != "true" || "$jar" != *slf4j*) ]]; then
           CP+=(${jar})
         fi
@@ -126,7 +126,7 @@ function combineClasspaths() {
 function filterSLF4J() {
   base="$1"
   CP=()
-  for jar in $(find ${base} -maxdepth 1 -type f -name "*.jar"); do
+  for jar in $(find -L ${base} -maxdepth 1 -type f -name "*.jar"); do
     if [[ "$jar" != *"slf4j"* ]]; then
       CP+=(${jar})
     fi
@@ -429,7 +429,7 @@ NL=$'\n'
 GEOMESA_OPTS="-Duser.timezone=UTC -DEPSG-HSQL.directory=/tmp/$(whoami)"
 GEOMESA_OPTS="${GEOMESA_OPTS} -Djava.awt.headless=true"
 GEOMESA_OPTS="${GEOMESA_OPTS} -Dlog4j.configuration=file://${GEOMESA_CONF_DIR}/log4j.properties"
-GEOMESA_OPTS="-Dgeomesa.home=${GEOMESA_CASSANDRA_HOME}"
+GEOMESA_OPTS="${GEOMESA_OPTS} -Dgeomesa.home=${GEOMESA_CASSANDRA_HOME}"
 GEOMESA_DEBUG_OPTS="-Xmx8192m -XX:-UseGCOverheadLimit -Xdebug -Xnoagent -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=9898"
 GEOMESA_CP=""
 
